Welcome to :mod:`pyvisfile`'s documentation!
============================================

Pyvisfile allows you to write a variety of visualization file formats,
including

* `Kitware's <https://www.kitware.com>`__
  `XML-style <https://vtk.org/documentation>`__
  `VTK <https://vtk.org>`__ data files.

* `XDMF <https://www.xdmf.org/index.php/Main_Page>`__ data files.

pyvisfile supports many mesh geometries, such such as unstructured
and rectangular structured meshes, particle meshes, as well as
scalar and vector variables on them. In addition, pyvisfile allows the
semi-automatic writing of parallelization-segmented visualization files
in VTK and XDMF formats.
For updates, downloads and support, please visit the `PyVisfile web page
<https://github.com/inducer/pyvisfile>`__.

.. module:: pyvisfile

Table of Contents
-----------------

.. toctree::
    :maxdepth: 2

    installing
    vtk
    xdmf
    faq
    🚀 Github <https://github.com/inducer/pyvisfile>
    💾 Download Releases <https://pypi.org/project/pyvisfile>

* :ref:`genindex`
